@@ -177,6 +177,30 @@ class Context(BaseModel):
     name: str
 
 
+class MCPServerConfig(BaseModel):
+    model_config = ConfigDict(extra="ignore")
+
+    command: str
+    args: Optional[list[str]]
+    env: Optional[dict[str, Any]] = None
+    auth_token: Optional[str] = None
+
+
+class MCPServerDetails(BaseModel):
+    model_config = ConfigDict(extra="ignore")
+
+    name: str
+    description: Optional[str]
+    enabled: bool
+    config: Optional[MCPServerConfig] = None
+    mcp_connect_url: Optional[str] = None
+    tools_tokens_size_limit: Optional[int] = None
+    command: Optional[str] = None
+    arguments: Optional[str] = None
+    settings: Optional[Integration] = None
+    mcp_connect_auth_token: Optional[Integration] = None
+
+
 class SystemPromptHistory(BaseModel):
     """Model for system prompt history."""
 
@@ -221,6 +245,8 @@ class Assistant(AssistantBase):
     top_p: Optional[float] = None
     context: List[Context] = Field(default_factory=list)
     user_abilities: Optional[List[Any]] = None
+    mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
+    assistant_ids: List[str] = Field(default_factory=list)
 
 
 class AssistantRequestBase(AssistantBase):
@@ -232,7 +258,7 @@ class AssistantRequestBase(AssistantBase):
     project: str
     context: List[Context] = Field(default_factory=list)
     llm_model_type: str
-    toolkits: List[ToolKitDetails]
+    toolkits: List[ToolKitDetails] = Field(default_factory=list)
     user_prompts: List[str] = Field(default_factory=list)
     shared: bool = False
     is_react: bool = False
@@ -240,6 +266,8 @@ class AssistantRequestBase(AssistantBase):
     slug: Optional[str] = None
     temperature: Optional[float] = None
     top_p: Optional[float] = None
+    mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
+    assistant_ids: List[str] = Field(default_factory=list)
 
 
 class AssistantCreateRequest(AssistantRequestBase):
